/*
 *  GuiLoader examples
 *  Copyright (c) 2006-2009 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifdef _WIN32
	#include <gdk/gdkwin32.h>
#endif

#include <glib/gi18n.h>
#include <guiloader.h> 

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

typedef struct _Application Application;

struct _Application {
	GuiLoader * loader;
	GtkWidget * window;
};

gboolean OnDeleteEvent(GtkWidget * widget, GdkEvent * event, Application * app) { 
	gtk_main_quit();
	return TRUE; 
}

void ApplicationInit(Application * app) {
	app->loader= gui_loader_new();

	GUIXML_DECL
		#include "hello.gui.h"
	GUIXML_LOAD(app->loader)

	app->window= gui_loader_bind_object(app->loader, "window1");
	gui_loader_connect_signal(app->loader, "onDeleteEvent", G_CALLBACK(OnDeleteEvent), app);
}
	
void ApplicationDone(Application * app) { 
	g_object_unref(app->loader); 
}

int Main(int argc, char ** argv) {
	Application app;

	gtk_init(&argc, &argv);
	guiloader_enter();

	#if ENABLE_NLS
		bindtextdomain(PACKAGE, LOCALEDIR);
		bind_textdomain_codeset(PACKAGE, "UTF-8");
		textdomain(PACKAGE);
	#endif

	ApplicationInit(&app);
	gtk_widget_show(app.window);
	gtk_main();
	ApplicationDone(&app);

	guiloader_leave();		
	return 0;
}

#ifdef _WIN32
	int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
		{ return Main(__argc, __argv); }
#else
	int main(int argc, char ** argv) 
		{ return Main(argc, argv); }
#endif
